@@ -372,13 +372,13 @@ pub fn is_host_port(string: String) -> Result<(), String> {
     parse_host_port(&string).map(|_| ())
 }
 
-#[cfg(windows)]
+#[cfg(any(windows, target_os = "ios"))]
 fn udp_socket(_reuseaddr: bool) -> io::Result<Socket> {
-    let sock = Socket::new(Domain::ipv4(), Type::dgram(), None)?;
+    let sock = Socket::new(Domain::IPV4, Type::DGRAM, None)?;
     Ok(sock)
 }
 
-#[cfg(not(windows))]
+#[cfg(not(any(windows, target_os = "ios")))]
 fn udp_socket(reuseaddr: bool) -> io::Result<Socket> {
     use {
         nix::sys::socket::{
@@ -388,7 +388,7 @@ fn udp_socket(reuseaddr: bool) -> io::Result<Socket> {
         std::os::unix::io::AsRawFd,
     };
 
-    let sock = Socket::new(Domain::ipv4(), Type::dgram(), None)?;
+    let sock = Socket::new(Domain::IPV4, Type::DGRAM, None)?;
     let sock_fd = sock.as_raw_fd();
 
     if reuseaddr {
@@ -424,7 +424,7 @@ pub fn bind_in_range(ip_addr: IpAddr, range: PortRange) -> io::Result<(u16, UdpS
         let addr = SocketAddr::new(ip_addr, port);
 
         if sock.bind(&SockAddr::from(addr)).is_ok() {
-            let sock = sock.into_udp_socket();
+            let sock: UdpSocket = sock.into();
             return Result::Ok((sock.local_addr().unwrap().port(), sock));
         }
     }
@@ -486,8 +486,7 @@ pub fn bind_to(ip_addr: IpAddr, port: u16, reuseaddr: bool) -> io::Result<UdpSoc
 
     let addr = SocketAddr::new(ip_addr, port);
 
-    sock.bind(&SockAddr::from(addr))
-        .map(|_| sock.into_udp_socket())
+    sock.bind(&SockAddr::from(addr)).map(|_| sock.into())
 }
 
 // binds both a UdpSocket and a TcpListener
@@ -501,7 +500,7 @@ pub fn bind_common(
     let addr = SocketAddr::new(ip_addr, port);
     let sock_addr = SockAddr::from(addr);
     sock.bind(&sock_addr)
-        .and_then(|_| TcpListener::bind(&addr).map(|listener| (sock.into_udp_socket(), listener)))
+        .and_then(|_| TcpListener::bind(&addr).map(|listener| (sock.into(), listener)))
 }
 
 pub fn find_available_port_in_range(ip_addr: IpAddr, range: PortRange) -> io::Result<u16> {
